@@ -498,6 +498,8 @@ def spec_image_to_srgb(image: np.ndarray,
                       wavelengths: Union[np.ndarray, List],
                       illuminant_name: str = 'E',
                       cmf_name: str = 'CIE 1931 2 Degree Standard Observer'):
+    """convert spectral image to RGB given image as np.ndarray, wavelength sampling, illuminant & color matching
+    functions (defaults to CIE 1931 RGB with equal energy (E) illuminant)"""
     import colour
 
     nc = image.shape[2]
@@ -512,9 +514,10 @@ def spec_image_to_srgb(image: np.ndarray,
     cmfs = deepcopy(colour.MSDS_CMFS[cmf_name])
     cmfs = cmfs.align(shape=spec_shape)
     image = colour.msds_to_XYZ(image, cmfs, illuminant, method='Integration', shape=spec_shape)
+    image /= 100
     if cmf_name.lower().startswith('cie'):
-        #
-        image = colour.XYZ_to_sRGB(image / 100)#, illuminant=colour.colorimetry.CCS_ILLUMINANTS[cmf_name][illuminant_name])
-    else:
-        image /= 100
+        # convert CIE XYZ to sRGB
+        image = colour.XYZ_to_sRGB(image,
+                                   illuminant=colour.colorimetry.CCS_ILLUMINANTS[cmf_name][illuminant_name],
+                                   apply_cctf_encoding=False)
     return image
