@@ -77,6 +77,18 @@ def dims_execpt(inp, dim):
     return tuple(np.r_[[d for d in range(inp.ndim) if d != dim]])
 
 
+def sizes_execpt(inp, dim):
+    """return all except the specified dimension indices"""
+    return [s for d, s in enumerate(inp.shape) if d != dim]
+
+
+def replace_dim(inp, dim: int, new_size: int):
+    """given input array or tensor, return shape of array with one of the dimensions (dim, can be negative) replaced
+     by the specified new size"""
+    nd = len(inp)
+    return [new_size if d == dim or dim < 0 and d == nd + dim else s for d, s in enumerate(inp)]
+
+
 def loadmat(filename):
     """wrapper around scipy.io.loadmat that avoids conversion of nested matlab structs to np.arrays"""
     import scipy.io as spio
@@ -224,6 +236,7 @@ def video_writer(filename: str, vcodec: str = 'libx264', framerate: float = 25,
 
 def write_video(filename: str, frames: Union[np.ndarray, list], offset: float = 0.0, scale: float = 1.0, gamma: float = 1.0,
                 masks: Union[np.ndarray, list, bool] = None, background: Union[np.ndarray, list, tuple] = None,
+                cycle: bool = False,
                 ffmpeg_path=None, verbosity: int = 0, **kwargs):
     """given a sequence of frames (as 4D np.ndarray or as list of 3D np.ndarrays), export a video using FFMPEG;
 
@@ -242,6 +255,10 @@ def write_video(filename: str, frames: Union[np.ndarray, list], offset: float =
     alternatively, the video sequence can be alpha blended against a background, either a constant value, color, or a
     static background image
 
+    cycle sequence
+    set cycle = True for poor man's looped animations where the reversed animation is prepended (doubling the number of
+    frames as a side effect)
+
     additional arguments:
     all additional arguments will by passed through to the ffmpeg video writer, examples are:
     vcodec: str = 'libx264'
@@ -260,7 +277,7 @@ def write_video(filename: str, frames: Union[np.ndarray, list], offset: float =
     if frames[0].dtype == np.uint8:
         if requires_tonemapping:
             raise Exception('frames are already in uint8 format but tonemapping is requested')
-        if masks[0].dtype != np.uint8:
+        if masks is not None and masks[0].dtype != np.uint8:
             raise Exception('frames are in uint8 format but masks are not')
         if background is not None:
             raise Exception('frames are already in uint8 format but alpha blending is requested (background != None)')
@@ -279,7 +296,13 @@ def write_video(filename: str, frames: Union[np.ndarray, list], offset: float =
         writer = video_writer(filename=filename, verbosity=verbosity, vcodec='gif', **kwargs)
     else:
         raise NotImplementedError('unexpected file extension: ' + ext)
-    for fi, frame in enumerate(frames):
+
+    frame_inds = np.r_[:len(frames)]
+    if cycle:
+        frame_inds = np.r_[frame_inds, frame_inds[::-1]]
+
+    for fi in frame_inds:
+        frame = frames[fi]
         if masks is not None:
             mask = masks[fi]
         else:
